@@ -49,6 +49,16 @@ impl<T: Payload + ParsePayload> ApiRequest for T {
         request: &Request,
         body: &mut RequestBody,
     ) -> Result<Self, ParseRequestError> {
+        match request.content_type() {
+            Some(content_type) if content_type != T::CONTENT_TYPE => {
+                return Err(ParseRequestError::ContentTypeNotSupported {
+                    content_type: content_type.to_string(),
+                })
+            }
+            Some(_) => {}
+            None => return Err(ParseRequestError::ExpectContentType),
+        }
+
         <T as ParsePayload>::from_request(request, body).await
     }
 }
