@@ -1,6 +1,6 @@
 use poem::{
     http::{header, Method, StatusCode, Uri},
-    web::Cookie,
+    web::cookie::Cookie,
     Endpoint, IntoEndpoint, Request,
 };
 use poem_openapi::{
@@ -164,8 +164,8 @@ async fn cookie() {
         }
     }
 
-    let api = OpenApiService::new(Api).into_endpoint();
-    let cookie = Cookie::new("v", "10");
+    let api = poem::warps_endpoint(OpenApiService::new(Api).into_endpoint());
+    let cookie = Cookie::new_with_str("v", "10");
     let resp = api
         .call(
             Request::builder()
@@ -188,7 +188,7 @@ async fn cookie_default() {
         }
     }
 
-    let api = OpenApiService::new(Api).into_endpoint();
+    let api = poem::warps_endpoint(OpenApiService::new(Api).into_endpoint());
     let resp = api.call(Request::builder().finish()).await;
     assert_eq!(resp.status(), StatusCode::OK);
 }
